@@ -5,6 +5,7 @@ import os
 import re
 import socket
 
+from stackifyapm.conf.constants import DEFAULT_CONFIG_FILE
 from stackifyapm.conf.constants import LOG_PATH
 from stackifyapm.utils import compat
 
@@ -122,7 +123,8 @@ class Config(_ConfigBase):
     instrument = _BoolConfigValue("DISABLE_INSTRUMENTATION", default=True)
     application_name = _ConfigValue("APPLICATION_NAME", default='Python Application')
     base_dir = _ConfigValue("BASE_DIR", default=None)
-    config_file = _ConfigValue("CONFIG_FILE", default='stackify.json')
+    config_file = _ConfigValue("CONFIG_FILE", default=DEFAULT_CONFIG_FILE)
+    multiprocessing = _BoolConfigValue("MULTIPROCESSING", default=False)
 
 
 class IncrementalFileHandler(logging.handlers.RotatingFileHandler):
@@ -211,14 +213,16 @@ def setup_logging(client):
         handler.namer = namer
 
         logger = logging.getLogger("stackify_apm")
+        logger.propagate = False
         logger.setLevel(logging.DEBUG)
         logger.addHandler(handler)
 
         # Set stackify-python-apm first log file to chmod 777
         os.chmod(filename, 0o777)
 
-        for logger_name in ["stackifyapm", "stackifyapm.traces", "stackifyapm.errors"]:
+        for logger_name in ["stackifyapm", "stackifyapm.traces", "stackifyapm.errors", "stackifyapm.instrument"]:
             _logger = logging.getLogger(logger_name)
+            _logger.propagate = False
             _logger.setLevel(logging.DEBUG)
 
             if "error" in logger_name:
